package wtalk.protocols.irc;

import java.io.*;
import java.net.*;


import wtalk.RMsgHandler;

class ReceivedListener extends Thread{
	private BufferedReader in=null;
	private IRCProtocol mIRC=null;
	private RMsgHandler rmh=null;	// generic message handler
	private RMsgHandler rwh = null;	// handles wall messages if !null
	private RMsgHandler rsh = null;	// handles system messages if !null
	private RMsgHandler rph = null;	// handles private messages if !null
	private RMsgHandler rah = null;	// handles automated messages if !null
	private StatusListener sl = null; //listens for status resposnes

	public ReceivedListener(){
		in = null; rmh = null; mIRC=null;
	}

	public void ListenTo(BufferedReader n){
		in = n;
	}

	public void ReportTo(RMsgHandler r){
		rmh = r;
	}

	public void ReportWallTo(RMsgHandler r){
		rwh = r;
	}

	public void ReportSystemTo(RMsgHandler r){
		rsh = r;
	}

	public void ReportPrivateTo(RMsgHandler r){
		rph = r;
	}

	public void ReportAutoTo(RMsgHandler r){
		rah = r;
	}

	public void setStatusListener(StatusListener s){
		sl = s;
	}

	public void setIRCProtocol(IRCProtocol irc) { mIRC = irc; };

	public void run(){
		String s;
		String target, from, data;
		IRCMessage message=null;

		if(in==null) return;

		while(true){

			try{
				s = in.readLine();
			} catch(IOException e){ return; }


			if(s==null) break;

			message = new IRCMessage(s);
			target = message.getReceiver();
			from = message.getSender();
			data = message.getText();

			if(message.isServerMsg()) {
				if(message.getCommand().equals("PING")){
					mIRC.sendPong(from, data);
				} else
				rsh.handle(target, from, data);
				System.out.println("debug: "+ s);
			} else if(message.isAutomatedMsg()) {
				if ( rah != null) {
					rah.handle(target, target, data);
				}
			} else if(!(target.charAt(0)=='&' || 
					target.charAt(0)=='#')) {
				rph.handle(target, from, data);
			} else {
				rmh.handle(target, from, data);
			}

			
		}

		in=null;

	}
}

